@@ -3,7 +3,7 @@ package Algorithm::Easing;
 use strict;
 use warnings;
 
-our $VERSION = '0.966';
+our $VERSION = '0.967';
 
 1;
 
@@ -76,7 +76,7 @@ For ease of use, there is an included Mediator class.  The Mediator class permit
 =head1 METHODS
 
 =head2 ease_none
-    Usage :
+    usage :
     
         Parameters : 
             Let t be time,
@@ -92,7 +92,7 @@ This method is used for a linear translation between two positive real whole int
 =cut
 
 =head2 ease_in
-    Usage :
+    usage :
     
         Parameters : 
             Let t be time,
@@ -109,7 +109,7 @@ This method is used to ease in between two positive real whole integers as an in
 =cut
 
 =head2 ease_out
-    Usage :
+    usage :
     
         Parameters : 
             Let t be time,
@@ -126,7 +126,7 @@ This method is used to ease out between two positive real whole integers as an i
 =cut
 
 =head2 ease_both
-    Usage :
+    usage :
     
         Parameters : 
             Let t be time,
