@@ -97,7 +97,7 @@ Algorithm::Easing::Backdraft - Calculate eased translations between two positive
 =cut
 
 =head2 ease_none
-    Usage :
+    usage :
     
         Parameters : 
             Let t be time,
@@ -114,7 +114,7 @@ This method is used for a linear translation between two positive real whole int
 =cut
 
 =head2 ease_in
-    Usage :
+    usage :
     
         Parameters : 
             Let t be time,
@@ -131,7 +131,7 @@ This method is used to ease in between two positive real whole integers as an in
 =cut
 
 =head2 ease_out
-    Usage :
+    usage :
     
         Parameters : 
             Let be time,
@@ -148,7 +148,7 @@ This method is used to ease out between two positive real whole integers as an i
 =cut
 
 =head2 ease_both
-    Usage :
+    usage :
     
         Parameters : 
             Let t be time,
