@@ -94,7 +94,7 @@ Algorithm::Easing::Circular - Calculate eased translations between two positive
 =cut
 
 =head2 ease_none
-    Usage :
+    usage :
     
         Parameters : 
             Let t be time,
@@ -111,7 +111,7 @@ This method is used for a linear translation between two positive real whole int
 =cut
 
 =head2 ease_in
-    Usage :
+    usage :
     
         Parameters : 
             Let t be time,
@@ -128,7 +128,7 @@ This method is used to ease in between two positive real whole integers as an in
 =cut
 
 =head2 ease_out
-    Usage :
+    usage :
     
         Parameters : 
             Let t be time,
@@ -145,7 +145,7 @@ This method is used to ease out between two positive real whole integers as an i
 =cut
 
 =head2 ease_both
-    Usage :
+    usage :
     
         Parameters : 
             Let t be time,
