@@ -92,7 +92,7 @@ Algorithm::Easing::Quadratic - Calculate eased translations between two positive
 =cut
 
 =head2 ease_none
-    Usage :
+    usage :
     
         Parameters : 
             Let t be time,
@@ -109,7 +109,7 @@ This method is used for a linear translation between two positive real whole int
 =cut
 
 =head2 ease_in
-    Usage :
+    usage :
     
         Parameters : 
             Let t be time,
@@ -126,7 +126,7 @@ This method is used to ease in between two positive real whole integers as an in
 =cut
 
 =head2 ease_out
-    Usage :
+    usage :
     
         Parameters : 
             Let t be time,
@@ -143,7 +143,7 @@ This method is used to ease in between two positive real whole integers as an in
 =cut
 
 =head2 ease_both
-    Usage :
+    usage :
     
         Parameters : 
             Let t be time,
